==> fade-0.0.6.tar.gz: fade-0.0.6/README.md <==
# FADE TEXT
```
# Module made by @venaxyt on Github
import fade

text = """
```
![](https://raw.githubusercontent.com/venaxyt/fade/main/images/normal.PNG)
```
"""
```
```
# Fading a ascii art text (purple-pink)
faded_text = fade.purplepink(text)
print(faded_text)
>>> Output :
```
> ![](https://raw.githubusercontent.com/venaxyt/fade/main/images/purple-pink.PNG)
```
# Fading a ascii art text (blue-green)
faded_text = fade.bluegreen(text)
print(faded_text)
>>> Output :
```
> ![](https://raw.githubusercontent.com/venaxyt/fade/main/images/blue-green.PNG)
```
# Fading a ascii art text (darkblue-blue)
faded_text = fade.water(text)
print(faded_text)
>>> Output :
```
> ![](https://raw.githubusercontent.com/venaxyt/fade/main/images/marin.PNG)
```
# Fading a ascii art text (yellow-red)
faded_text = fade.fire(text)
print(faded_text)
>>> Output :
```
> ![](https://raw.githubusercontent.com/venaxyt/fade/main/images/fire.PNG)
```
# Fading a ascii art text (pink-red)
faded_text = fade.pinkred(text)
print(faded_text)
>>> Output :
```
> ![](https://raw.githubusercontent.com/venaxyt/fade/main/images/pink-red.PNG)
```
# Fading a ascii art text (purple-blue)
faded_text = fade.purpleblue(text)
print(faded_text)
>>> Output :
```
> ![](https://raw.githubusercontent.com/venaxyt/fade/main/images/purple-blue.PNG)
```
# Fading a ascii art text (green-yellow)
faded_text = fade.brazil(text)
print(faded_text)
>>> Output :
```
> ![](https://raw.githubusercontent.com/venaxyt/fade/main/images/brazil.PNG)
```
# Fading a ascii art text (random)
faded_text = fade.random(text)
print(faded_text)
>>> Output :
```
> ![](https://raw.githubusercontent.com/venaxyt/fade/main/images/random.PNG)

==> fade-0.0.7.tar.gz: fade-0.0.7/README.md <==
# FADE TEXT
```
# Module made by @venaxyt on Github
import fade

text = """
```
![](https://raw.githubusercontent.com/venaxyt/fade/main/images/normal.PNG)
```
"""
```
```
# Fading a ascii art text (black-white)
faded_text = fade.blackwhite(text)
print(faded_text)
>>> Output :
```
> ![](https://raw.githubusercontent.com/venaxyt/fade/main/images/black-white.PNG)
```
```
# Fading a ascii art text (purple-pink)
faded_text = fade.purplepink(text)
print(faded_text)
>>> Output :
```
> ![](https://raw.githubusercontent.com/venaxyt/fade/main/images/purple-pink.PNG)
```
# Fading a ascii art text (blue-green)
faded_text = fade.bluegreen(text)
print(faded_text)
>>> Output :
```
> ![](https://raw.githubusercontent.com/venaxyt/fade/main/images/blue-green.PNG)
```
# Fading a ascii art text (darkblue-blue)
faded_text = fade.water(text)
print(faded_text)
>>> Output :
```
> ![](https://raw.githubusercontent.com/venaxyt/fade/main/images/marin.PNG)
```
# Fading a ascii art text (yellow-red)
faded_text = fade.fire(text)
print(faded_text)
>>> Output :
```
> ![](https://raw.githubusercontent.com/venaxyt/fade/main/images/fire.PNG)
```
# Fading a ascii art text (pink-red)
faded_text = fade.pinkred(text)
print(faded_text)
>>> Output :
```
> ![](https://raw.githubusercontent.com/venaxyt/fade/main/images/pink-red.PNG)
```
# Fading a ascii art text (purple-blue)
faded_text = fade.purpleblue(text)
print(faded_text)
>>> Output :
```
> ![](https://raw.githubusercontent.com/venaxyt/fade/main/images/purple-blue.PNG)
```
# Fading a ascii art text (green-yellow)
faded_text = fade.brazil(text)
print(faded_text)
>>> Output :
```
> ![](https://raw.githubusercontent.com/venaxyt/fade/main/images/brazil.PNG)
```
# Fading a ascii art text (random)
faded_text = fade.random(text)
print(faded_text)
>>> Output :
```
> ![](https://raw.githubusercontent.com/venaxyt/fade/main/images/random.PNG)
